{% load sovtimer_versioned_static %}

<link rel="stylesheet" href="{% sovtimer_static 'sovtimer/css/aa-bootstrap-fix.min.css' %}">
<link rel="stylesheet" href="{% sovtimer_static 'sovtimer/css/aa-sov-timer.min.css' %}">
