# Generated by Django 4.0.3 on 2022-05-25 12:26

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sovtimer", "0007_cleanup_models"),
    ]

    operations = [
        migrations.AlterField(
            model_name="campaign",
            name="attackers_score",
            field=models.FloatField(default=0.4),
        ),
    ]
