{% extends "sovtimer/base.html" %}

{% load i18n %}

{% block sovtimer_header %}
    {% translate "Sovereignty Timers" as translated_header %}
    {% include "sovtimer/partials/header/h1.html" with header_text=translated_header %}
{% endblock %}

{% block sovtimer_body %}
    {% include "sovtimer/partials/dashboard/table.html" %}

    <script>
        const aaSovtimerSettings = {
            url: {
                ajaxUpdate: '{% url "sovtimer:dashboard_data" %}'
            },
            dateformat: 'YYYY-MM-DD HH:mm:ss',
            translations: {
                system: '{% translate "System" %}',
                constellation: '{% translate "Constellation" %}',
                region: '{% translate "Region" %}',
                owner: '{% translate "Owner / Defender" %}',
                activeCampaign: '{% translate "Active Campaign" %}',
                yes: '{% translate "Yes" %}',
                no: '{% translate "No" %}'
            }
        };
    </script>
{% endblock %}

{% block extra_css %}
    {% include "bundles/datatables-css.html" %}
    {% include "sovtimer/bundles/aa-sov-timer-css.html" %}
{% endblock %}

{% block extra_javascript %}
    {% include "bundles/moment-js.html" with locale=True %}
    {% include "bundles/datatables-js.html" %}
    {% include "bundles/filterdropdown-js.html" %}

    {% include "sovtimer/bundles/datatables-datetime-js.html" %}
    {% include "sovtimer/bundles/aa-sov-timer-js.html" %}
{% endblock %}
